==> istio-model-1.0.1-sources.jar: me/snowdrop/istio/mixer/adapter/redisquota/QuotaFluent.java <==
package me.snowdrop.istio.mixer.adapter.redisquota;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Deprecated;
import javax.validation.Valid;
import java.lang.Long;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface QuotaFluent<A extends me.snowdrop.istio.mixer.adapter.redisquota.QuotaFluent<A>> extends Fluent<A>{


    public Long getBucketDuration();
    public A withBucketDuration(Long bucketDuration);
    public Boolean hasBucketDuration();
    public A withNewBucketDuration(String arg1);
    public A withNewBucketDuration(long arg1);
    public Long getMaxAmount();
    public A withMaxAmount(Long maxAmount);
    public Boolean hasMaxAmount();
    public A withNewMaxAmount(String arg1);
    public A withNewMaxAmount(long arg1);
    public String getName();
    public A withName(String name);
    public Boolean hasName();
    public A addToOverrides(int index,me.snowdrop.istio.mixer.adapter.redisquota.Override item);
    public A setToOverrides(int index,me.snowdrop.istio.mixer.adapter.redisquota.Override item);
    public A addToOverrides(me.snowdrop.istio.mixer.adapter.redisquota.Override... items);
    public A addAllToOverrides(Collection<me.snowdrop.istio.mixer.adapter.redisquota.Override> items);
    public A removeFromOverrides(me.snowdrop.istio.mixer.adapter.redisquota.Override... items);
    public A removeAllFromOverrides(Collection<me.snowdrop.istio.mixer.adapter.redisquota.Override> items);
    
/**
 * This method has been deprecated, please use method buildOverrides instead.
 * @return The buildable object.
 */
@Deprecated public List<me.snowdrop.istio.mixer.adapter.redisquota.Override> getOverrides();
    public List<me.snowdrop.istio.mixer.adapter.redisquota.Override> buildOverrides();
    public me.snowdrop.istio.mixer.adapter.redisquota.Override buildOverride(int index);
    public me.snowdrop.istio.mixer.adapter.redisquota.Override buildFirstOverride();
    public me.snowdrop.istio.mixer.adapter.redisquota.Override buildLastOverride();
    public me.snowdrop.istio.mixer.adapter.redisquota.Override buildMatchingOverride(io.fabric8.kubernetes.api.builder.Predicate<me.snowdrop.istio.mixer.adapter.redisquota.OverrideBuilder> predicate);
    public A withOverrides(List<me.snowdrop.istio.mixer.adapter.redisquota.Override> overrides);
    public A withOverrides(me.snowdrop.istio.mixer.adapter.redisquota.Override... overrides);
    public Boolean hasOverrides();
    public QuotaFluent.OverridesNested<A> addNewOverride();
    public QuotaFluent.OverridesNested<A> addNewOverrideLike(me.snowdrop.istio.mixer.adapter.redisquota.Override item);
    public QuotaFluent.OverridesNested<A> setNewOverrideLike(int index,me.snowdrop.istio.mixer.adapter.redisquota.Override item);
    public QuotaFluent.OverridesNested<A> editOverride(int index);
    public QuotaFluent.OverridesNested<A> editFirstOverride();
    public QuotaFluent.OverridesNested<A> editLastOverride();
    public QuotaFluent.OverridesNested<A> editMatchingOverride(io.fabric8.kubernetes.api.builder.Predicate<me.snowdrop.istio.mixer.adapter.redisquota.OverrideBuilder> predicate);
    public QuotaAlgorithm getRateLimitAlgorithm();
    public A withRateLimitAlgorithm(QuotaAlgorithm rateLimitAlgorithm);
    public Boolean hasRateLimitAlgorithm();
    public Long getValidDuration();
    public A withValidDuration(Long validDuration);
    public Boolean hasValidDuration();
    public A withNewValidDuration(String arg1);
    public A withNewValidDuration(long arg1);

    public interface OverridesNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,me.snowdrop.istio.mixer.adapter.redisquota.OverrideFluent<QuotaFluent.OverridesNested<N>>{

        
    public N and();    public N endOverride();
}


}

==> istio-model-1.1.1-sources.jar: me/snowdrop/istio/mixer/adapter/redisquota/QuotaFluent.java <==
package me.snowdrop.istio.mixer.adapter.redisquota;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Integer;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface QuotaFluent<A extends me.snowdrop.istio.mixer.adapter.redisquota.QuotaFluent<A>> extends Fluent<A>{


    public Integer getBucketDuration();
    public A withBucketDuration(Integer bucketDuration);
    public Boolean hasBucketDuration();
    public Integer getMaxAmount();
    public A withMaxAmount(Integer maxAmount);
    public Boolean hasMaxAmount();
    public String getName();
    public A withName(String name);
    public Boolean hasName();
    public A withNewName(String arg1);
    public A withNewName(StringBuilder arg1);
    public A withNewName(StringBuffer arg1);
    public A addToOverrides(int index,me.snowdrop.istio.mixer.adapter.redisquota.Override item);
    public A setToOverrides(int index,me.snowdrop.istio.mixer.adapter.redisquota.Override item);
    public A addToOverrides(me.snowdrop.istio.mixer.adapter.redisquota.Override... items);
    public A addAllToOverrides(Collection<me.snowdrop.istio.mixer.adapter.redisquota.Override> items);
    public A removeFromOverrides(me.snowdrop.istio.mixer.adapter.redisquota.Override... items);
    public A removeAllFromOverrides(Collection<me.snowdrop.istio.mixer.adapter.redisquota.Override> items);
    public A removeMatchingFromOverrides(io.fabric8.kubernetes.api.builder.Predicate<me.snowdrop.istio.mixer.adapter.redisquota.OverrideBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildOverrides instead.
 * @return The buildable object.
 */
@Deprecated public List<me.snowdrop.istio.mixer.adapter.redisquota.Override> getOverrides();
    public List<me.snowdrop.istio.mixer.adapter.redisquota.Override> buildOverrides();
    public me.snowdrop.istio.mixer.adapter.redisquota.Override buildOverride(int index);
    public me.snowdrop.istio.mixer.adapter.redisquota.Override buildFirstOverride();
    public me.snowdrop.istio.mixer.adapter.redisquota.Override buildLastOverride();
    public me.snowdrop.istio.mixer.adapter.redisquota.Override buildMatchingOverride(io.fabric8.kubernetes.api.builder.Predicate<me.snowdrop.istio.mixer.adapter.redisquota.OverrideBuilder> predicate);
    public Boolean hasMatchingOverride(io.fabric8.kubernetes.api.builder.Predicate<me.snowdrop.istio.mixer.adapter.redisquota.OverrideBuilder> predicate);
    public A withOverrides(List<me.snowdrop.istio.mixer.adapter.redisquota.Override> overrides);
    public A withOverrides(me.snowdrop.istio.mixer.adapter.redisquota.Override... overrides);
    public Boolean hasOverrides();
    public QuotaFluent.OverridesNested<A> addNewOverride();
    public QuotaFluent.OverridesNested<A> addNewOverrideLike(me.snowdrop.istio.mixer.adapter.redisquota.Override item);
    public QuotaFluent.OverridesNested<A> setNewOverrideLike(int index,me.snowdrop.istio.mixer.adapter.redisquota.Override item);
    public QuotaFluent.OverridesNested<A> editOverride(int index);
    public QuotaFluent.OverridesNested<A> editFirstOverride();
    public QuotaFluent.OverridesNested<A> editLastOverride();
    public QuotaFluent.OverridesNested<A> editMatchingOverride(io.fabric8.kubernetes.api.builder.Predicate<me.snowdrop.istio.mixer.adapter.redisquota.OverrideBuilder> predicate);
    public QuotaAlgorithm getRateLimitAlgorithm();
    public A withRateLimitAlgorithm(QuotaAlgorithm rateLimitAlgorithm);
    public Boolean hasRateLimitAlgorithm();
    public Integer getValidDuration();
    public A withValidDuration(Integer validDuration);
    public Boolean hasValidDuration();

    public interface OverridesNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,me.snowdrop.istio.mixer.adapter.redisquota.OverrideFluent<QuotaFluent.OverridesNested<N>>{

        
    public N and();    public N endOverride();
}


}
